[![pypi](https://img.shields.io/badge/pypi-json_management-blue)](https://pypi.org/project/manage-json/) [![tele](https://img.shields.io/badge/telegram-@geko1-blue)](https://t.me/geko1) [![Documentation Status](https://readthedocs.org/projects/json-management/badge/?version=latest)](https://json-management.readthedocs.io/en/latest/?badge=latest)


```powershell
pip install -U json-management
```
